@@ -45,7 +45,7 @@ METRICS_INSERT_CQL = ('update monasca.metrics USING TTL ? '
                       'and dimension_names = ?')
 
 METRICS_UPDATE_CQL = ('update monasca.metrics USING TTL ? '
-                      'set updated_at = ? '
+                      'set metric_id = ?, updated_at = ? '
                       'where region = ? and tenant_id = ? and metric_name = ? and dimensions = ? '
                       'and dimension_names = ?')
 
@@ -136,6 +136,8 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
             hash_string = '%s\0%s\0%s\0%s' % (region, tenant_id, metric_name, '\0'.join(dim_list))
             metric_id = hashlib.sha1(hash_string.encode('utf8')).hexdigest()
 
+            # TODO(brtknr): If database per tenant becomes the default and the
+            # only option, recording tenant_id will be redundant.
             metric = Metric(id=metric_id,
                             region=region,
                             tenant_id=tenant_id,
@@ -156,6 +158,7 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
                 self._metric_batch.add_measurement_query(measurement_bound_stmt)
 
                 metric_update_bound_stmt = self._metric_update_stmt.bind((self._retention,
+                                                                          id_bytes,
                                                                           metric.time_stamp,
                                                                           metric.region,
                                                                           metric.tenant_id,
@@ -164,7 +167,7 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
                                                                           metric.dimension_names))
                 self._metric_batch.add_metric_query(metric_update_bound_stmt)
 
-                return metric
+                return metric, tenant_id
 
             self._metric_id_cache[metric.id] = metric.id
 
@@ -215,19 +218,17 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
                  metric.time_stamp))
             self._metric_batch.add_measurement_query(measurement_insert_bound_stmt)
 
-            return metric
-
-    def write_batch(self, metrics):
+            return metric, tenant_id
 
+    def write_batch(self, metrics_by_tenant):
+        # TODO(brtknr): At the moment, Cassandra does not have database per
+        # tenant implemented, so join the list of values.
+        metrics = metrics_by_tenant.chained()
         with self._lock:
             batch_list = self._metric_batch.get_all_batches()
-
             results = execute_concurrent(self._session, batch_list, raise_on_first_error=True)
-
             self._handle_results(results)
-
             self._metric_batch.clear()
-
             LOG.info("flushed %s metrics", len(metrics))
 
     @staticmethod
