@@ -13,36 +13,57 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from abc import ABCMeta
 import os
 
 from oslo_config import cfg
 from oslo_log import log
+import six
 
-from monasca_common.kafka import consumer
+from monasca_persister.repositories import singleton
 
 LOG = log.getLogger(__name__)
 
+class DataPoints(dict):
 
-class Persister(object):
+    def __init__(self):
+        self.counter = 0
 
-    def __init__(self, kafka_conf, zookeeper_conf, repository):
+    def __setitem__(self, key, value):
+        raise NotImplementedError('Use append(key, value) instead.')
 
-        self._data_points = []
+    def __delitem__(self, key):
+        raise NotImplementedError('Use clear() instead.')
+
+    def pop(self):
+        raise NotImplementedError('Use clear() instead.')
+
+    def popitem(self):
+        raise NotImplementedError('Use clear() instead.')
+
+    def update(self):
+        raise NotImplementedError('Use clear() instead.')
+
+    def chained(self):
+        return [vi for vo in super(DataPoints, self).values() for vi in vo]
+
+    def append(self, key, value):
+        super(DataPoints, self).setdefault(key, []).append(value)
+        self.counter += 1
+
+    def clear(self):
+        super(DataPoints, self).clear()
+        self.counter = 0
+
+
+@six.add_metaclass(singleton.Singleton)
+class Persister(six.with_metaclass(ABCMeta, object)):
+
+    def __init__(self, kafka_conf, repository):
+        self._data_points = DataPoints()
 
         self._kafka_topic = kafka_conf.topic
-
         self._batch_size = kafka_conf.batch_size
-
-        self._consumer = consumer.KafkaConsumer(
-            kafka_conf.uri,
-            zookeeper_conf.uri,
-            kafka_conf.zookeeper_path,
-            kafka_conf.group_id,
-            kafka_conf.topic,
-            repartition_callback=self._flush,
-            commit_callback=self._flush,
-            commit_timeout=kafka_conf.max_wait_time_seconds)
-
         self.repository = repository()
 
     def _flush(self):
@@ -53,20 +74,20 @@ class Persister(object):
             self.repository.write_batch(self._data_points)
 
             LOG.info("Processed {} messages from topic '{}'".format(
-                len(self._data_points), self._kafka_topic))
+                self._data_points.counter, self._kafka_topic))
 
-            self._data_points = []
+            self._data_points.clear()
             self._consumer.commit()
         except Exception as ex:
-            if "partial write: points beyond retention policy dropped" in ex.message:
+            if "partial write: points beyond retention policy dropped" in str(ex):
                 LOG.warning("Some points older than retention policy were dropped")
-                self._data_points = []
+                self._data_points.clear()
                 self._consumer.commit()
 
             elif cfg.CONF.repositories.ignore_parse_point_error \
-                    and "unable to parse points" in ex.message:
-                LOG.warning("Some points unable to parse were dropped")
-                self._data_points = []
+                    and "unable to parse" in str(ex):
+                LOG.warning("Some points were unable to be parsed and were dropped")
+                self._data_points.clear()
                 self._consumer.commit()
 
             else:
@@ -76,16 +97,15 @@ class Persister(object):
 
     def run(self):
         try:
-            for raw_message in self._consumer:
+            for message in self._consumer:
                 try:
-                    message = raw_message[1]
-                    data_point = self.repository.process_message(message)
-                    self._data_points.append(data_point)
+                    data_point, tenant_id = self.repository.process_message(message)
+                    self._data_points.append(tenant_id, data_point)
                 except Exception:
                     LOG.exception('Error processing message. Message is '
                                   'being dropped. {}'.format(message))
 
-                if len(self._data_points) >= self._batch_size:
+                if self._data_points.counter >= self._batch_size:
                     self._flush()
         except Exception:
             LOG.exception(
